@@ -25,7 +25,7 @@
   (See COPYING.txt)
 
   June 14, 2002 - February 24, 2010
-  $Id: compiler.h,v 1.8 2013/11/04 19:17:33 scottmc Exp $
+  $Id: compiler.h,v 1.7 2010/02/25 07:06:15 wkendrick Exp $
 */
 
 #ifdef WIN32
@@ -58,7 +58,7 @@
 
 
 
-#ifndef __HAIKU__
+
 #ifdef __GNUC__
 // This version has strict type checking for safety.
 // See the "unnecessary" pointer comparison. (from Linux)
@@ -76,7 +76,6 @@
 #define min(a,b) (((a) < (b)) ? (a) : (b))
 #define max(a,b) (((a) > (b)) ? (a) : (b))
 #endif
-#endif /* Not Haiku */
 
 #define clamp(lo,value,hi)    (min(max(value,lo),hi))
 
