@@ -1,7 +1,7 @@
 /*
   fonts.c
 
-  Copyright (c) 2009-2014
+  Copyright (c) 2009
   http://www.tuxpaint.org/
 
   This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  $Id: fonts.c,v 1.39 2014/04/19 18:36:26 wkendrick Exp $
+  $Id: fonts.c,v 1.33 2010/04/27 22:04:44 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -75,19 +75,13 @@
 #ifdef __APPLE__
 #include "wrapperdata.h"
 extern WrapperData macosx;
-#endif
 
 /* system fonts that cause TTF_OpenFont to crash */
 static const char *problemFonts[] = {
   "/Library/Fonts//AppleMyungjo.ttf",
   NULL
 };
-
-/* font types that cause TTF_OpenFont to crash */
-static const char *problemFontExtensions[] = {
-  ".pfb", /* Ubuntu 14.04 (libsdl-ttf2.0-0 2.0.11-3, libfreetype6 2.5.2-1ubuntu2) -bjk 2014.04.19 */
-  NULL
-};
+#endif
 
 #ifdef FORKED_FONTS
 
@@ -129,6 +123,8 @@ SDL_Thread *font_thread;
 
 #endif
 
+#include "tuxpaint.h"
+
 
 #ifdef FORKED_FONTS
 int no_system_fonts;
@@ -158,6 +154,36 @@ unsigned text_size = 4;		// initial text size
 int button_label_y_nudge;
 
 
+/* Unfortunately, there is a bug in SDL_ttf-2.0.6, the current version
+   that causes a segmentation fault if an attempt is made to call
+   TTF_OpenFont() with the filename of a font that doesn't exist. This
+   is an old and well documented bug that is fixed in CVS.
+*/
+
+/* FIXME: SDL_ttf is up to 2.0.8, so we can probably fully remove this
+   -bjk 2007.06.05 */
+
+/*
+
+TTF_Font *BUGFIX_TTF_OpenFont206(const char *const file, int ptsize)
+{
+  FILE *fp;
+
+#ifdef DEBUG
+  printf("Loading font: %s\n", file);
+#endif
+
+  if ((fp = fopen(file, "rb")) == NULL)
+    return NULL;
+  fclose(fp);
+
+#undef TTF_OpenFont
+  return TTF_OpenFont(file, ptsize);
+}
+*/
+
+/* #define TTF_OpenFont    BUGFIX_TTF_OpenFont206 */
+
 #ifndef NO_SDLPANGO
 static TuxPaint_Font *try_alternate_font(int size)
 {
@@ -169,7 +195,7 @@ static TuxPaint_Font *try_alternate_font(int size)
   if ((p = strrchr(prefix, '_')) != NULL)
   {
     *p = 0;
-    snprintf(str, sizeof(str), "%sfonts/locale/%s.ttf", DATA_PREFIX, prefix);
+    snprintf(str, sizeof(str), "%s/fonts/locale/%s.ttf", DATA_PREFIX, prefix);
 
     return TuxPaint_Font_OpenFont("", str, size);
   }
@@ -189,14 +215,14 @@ TuxPaint_Font *load_locale_font(TuxPaint_Font * fallback, int size)
   else
   {
     char str[128];
-    snprintf(str, sizeof(str), "%sfonts/locale/%s.ttf", DATA_PREFIX, lang_prefix);
+    snprintf(str, sizeof(str), "%s/fonts/locale/%s.ttf", DATA_PREFIX, lang_prefix);
 
     ret = TuxPaint_Font_OpenFont("", str, size);
 
 #ifdef __APPLE__
     if (!ret)
     {
-      snprintf(str, sizeof(str), "%sfonts/%s.ttf", DATA_PREFIX, lang_prefix);
+      snprintf(str, sizeof(str), "%s/fonts/%s.ttf", DATA_PREFIX, lang_prefix);
       ret = TuxPaint_Font_OpenFont("", str, size);
     }
 
@@ -235,48 +261,25 @@ TuxPaint_Font *load_locale_font(TuxPaint_Font * fallback, int size)
 
 void TuxPaint_Font_CloseFont(TuxPaint_Font * tpf)
 {
-#ifdef DEBUG
-  printf("TuxPaint_Font_CloseFont step 1 (%p)\n", tpf); //EP
-#endif
-  if (!tpf) return;     //EP
-        
 #ifndef NO_SDLPANGO
-#ifdef DEBUG
-  printf("TuxPaint_Font_CloseFont step 2 (%p, %d)\n", tpf->pango_context, tpf->typ);    //EP
-#endif
   if (tpf->typ == FONT_TYPE_PANGO)
-          if (tpf->pango_context)       //EP
   {
-#ifndef __APPLE__       //EP added ifdef because SDLPango_FreeContext sometimes crashed with "pointer being freed was not allocated"
-        SDLPango_FreeContext(tpf->pango_context);
-#endif
-        tpf->pango_context = NULL;
+    SDLPango_FreeContext(tpf->pango_context);
+    tpf->pango_context = NULL;
   }
 #endif
 
-#ifdef DEBUG
-  printf("TuxPaint_Font_CloseFont step 3 (%p, %d)\n", tpf->ttf_font, tpf->typ); //EP
-  fflush(stdout);
-#endif
   if (tpf->typ == FONT_TYPE_TTF)
-          if (tpf->ttf_font)    //EP
   {
     TTF_CloseFont(tpf->ttf_font);
     tpf->ttf_font = NULL;
   }
-
-  if (tpf->desc != NULL) {
-    free(tpf->desc);
-    tpf->desc = NULL;
-  }
-
   free(tpf);
 }
 
 TuxPaint_Font *TuxPaint_Font_OpenFont(const char *pangodesc, const char *ttffilename, int size)
 {
   TuxPaint_Font *tpf = NULL;
-  int i;
 #ifndef NO_SDLPANGO
   char desc[1024];
 #endif
@@ -292,7 +295,6 @@ TuxPaint_Font *TuxPaint_Font_OpenFont(const char *pangodesc, const char *ttffile
     tpf = (TuxPaint_Font *) malloc(sizeof(TuxPaint_Font));
     tpf->typ = FONT_TYPE_PANGO;
     snprintf(desc, sizeof(desc), "%s %d", pangodesc, (size * 3) / 4);
-    tpf->desc = strdup(desc);
 
 #ifdef DEBUG
     printf("Creating context: \"%s\"\n", desc);
@@ -326,30 +328,25 @@ TuxPaint_Font *TuxPaint_Font_OpenFont(const char *pangodesc, const char *ttffile
     fflush(stdout);
 #endif
 
-    i = 0;
+#ifdef __APPLE__
+    int i = 0;
     while (problemFonts[i] != NULL)
     {
       if (!strcmp(ttffilename, problemFonts[i++]))
 	return NULL;		/* bail on known problematic fonts that cause TTF_OpenFont to crash */
     }
+#endif
 
-    i = 0;
-    while (problemFontExtensions[i] != NULL)
+    char fname_buf[MAX_PATH];
+    if (ttffilename[0] != '/')
     {
-      if (strstr(ttffilename, problemFontExtensions[i++]))
-	return NULL;		/* bail on known problematic font types that cause TTF_OpenFont to crash */
+      snprintf(fname_buf, sizeof(fname_buf), "%s/%s", DATA_PREFIX, ttffilename);
+      ttffilename = fname_buf;
     }
 
     tpf = (TuxPaint_Font *) malloc(sizeof(TuxPaint_Font));
     tpf->typ = FONT_TYPE_TTF;
     tpf->ttf_font = TTF_OpenFont(ttffilename, size);
-    tpf->desc = strdup(ttffilename);
-
-#ifdef DEBUG
-    printf("Loaded %s: %d->%d\n", ttffilename, tpf, tpf->ttf_font);
-    fflush(stdout);
-#endif
-
     if (tpf->ttf_font == NULL)
     {
 #ifdef DEBUG
@@ -878,6 +875,8 @@ static void groupfonts(void)
   user_font_styles = NULL;	// just to catch bugs
 
   qsort(user_font_families, num_font_families, sizeof user_font_families[0], compar_fontkiller);
+  //printf(stderr, "groupfonts() qsort(user_font_families 1...)\n");
+  //fflush(stdout);
   low = 0;
   for (;;)
   {
@@ -945,10 +944,12 @@ static void loadfonts(SDL_Surface * screen, const char *const dir)
 /* static */ int load_user_fonts(SDL_Surface * screen, void *vp, const char *restrict const locale)
 {
   char *homedirdir;
+  char str[MAX_PATH];
 
   (void) vp;			// junk passed by threading library
 
-  loadfonts_locale_filter(screen, DATA_PREFIX "fonts", locale);
+  snprintf(str, sizeof(str), "%s/fonts", DATA_PREFIX);
+  loadfonts_locale_filter(screen, str, locale);
 
   if (!no_system_fonts)
   {
@@ -960,16 +961,6 @@ static void loadfonts(SDL_Surface * screen, const char *const dir)
     loadfonts(screen, "/boot/home/config/font/ttffonts");
     loadfonts(screen, "/usr/share/fonts");
     loadfonts(screen, "/usr/X11R6/lib/X11/fonts");
-#elif defined(__HAIKU__)
-       dev_t volume = dev_for_path("/boot");
-       char buffer[B_PATH_NAME_LENGTH+B_FILE_NAME_LENGTH];
-       status_t result;
-    result = find_directory(B_SYSTEM_FONTS_DIRECTORY, volume, false, buffer, sizeof(buffer));
-       loadfonts(screen, buffer);
-    result = find_directory(B_COMMON_FONTS_DIRECTORY, volume, false, buffer, sizeof(buffer));
-       loadfonts(screen, buffer);
-    result = find_directory(B_USER_FONTS_DIRECTORY, volume, false, buffer, sizeof(buffer));
-       loadfonts(screen, buffer);
 #elif defined(__APPLE__)
     loadfonts(screen, "/System/Library/Fonts");
     loadfonts(screen, "/Library/Fonts");
@@ -1298,7 +1289,7 @@ TuxPaint_Font *getfonthandle(int desire)
   }
   else
   {
-#ifdef DEBUG    //EP fixed typo: replaced DBEUG with DEBUG
+#ifdef DBEUG
     printf("fi->filename is NULL\n");
     fflush(stdout);
 #endif
@@ -1309,8 +1300,7 @@ TuxPaint_Font *getfonthandle(int desire)
   if (fi->handle)
   {
 #ifdef DEBUG
-          printf("fi->handle was set (0x%x)\n", (int)(intptr_t) fi->handle);            //EP added (intptr_t) to avoid warning on x64
-
+    printf("fi->handle was set (0x%x)\n", (int) fi->handle);
     fflush(stdout);
 #endif
     return fi->handle;
