@@ -176,22 +176,22 @@ const char *const tool_tips[NUM_TOOLS] = {
 /* Tool icon filenames: */
 
 const char *const tool_img_fnames[NUM_TOOLS] = {
-  DATA_PREFIX "images/tools/brush.png",
-  DATA_PREFIX "images/tools/stamp.png",
-  DATA_PREFIX "images/tools/lines.png",
-  DATA_PREFIX "images/tools/shapes.png",
-  DATA_PREFIX "images/tools/text.png",
-  DATA_PREFIX "images/tools/label.png",
-  DATA_PREFIX "images/ui/dead40x40.png",
-  DATA_PREFIX "images/tools/magic.png",
-  DATA_PREFIX "images/tools/undo.png",
-  DATA_PREFIX "images/tools/redo.png",
-  DATA_PREFIX "images/tools/eraser.png",
-  DATA_PREFIX "images/tools/new.png",
-  DATA_PREFIX "images/tools/open.png",
-  DATA_PREFIX "images/tools/save.png",
-  DATA_PREFIX "images/tools/print.png",
-  DATA_PREFIX "images/tools/quit.png"
+  "images/tools/brush.png",
+  "images/tools/stamp.png",
+  "images/tools/lines.png",
+  "images/tools/shapes.png",
+  "images/tools/text.png",
+  "images/tools/label.png",
+  "images/ui/dead40x40.png",
+  "images/tools/magic.png",
+  "images/tools/undo.png",
+  "images/tools/redo.png",
+  "images/tools/eraser.png",
+  "images/tools/new.png",
+  "images/tools/open.png",
+  "images/tools/save.png",
+  "images/tools/print.png",
+  "images/tools/quit.png"
 };
 
 
